/*====================================+=====================================+
! File sc_version.h                   ! Copyright (C) 2018-2020 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This is free software: you can redistribute it and/or modify it under the !
! terms of the GNU General Public License as published by the Free Software !
! Foundation, either version 3 of the License, or any later version.        !
! This application is distributed in the hope that it will be useful, but   !
! WITHOUT ANY WARRANTY; without even the implied warranty of                !
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General !
! Public License for more details.                                          !
! You should have received a copy of the GNU General Public License along   !
! with this application. If not, see <http://www.gnu.org/licenses/>.        !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#pragma once
/*-------------------------------------------------------------------------*/
#include "common/sc_download.h"
/*-------------------------------------------------------------------------*/



/*--( Scarabee Common )----------------------------------------------------*/
namespace sc
{
/*-------------------------------------------------------------------------*/
class CAvailableVersionData
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CAvailableVersionData( const wxString &s_data ) ;
      //~CDlgVersion() ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      wxString m_s_version ;
      wxString m_s_url_download ; // This system's download url, if any
      wxString m_s_version_history ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CDlgVersion : public wxDialog
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CDlgVersion( wxWindow *parent,
                   const wxString &s_main_info,
                   const CAvailableVersionData &avd
                 ) ;
      //~CDlgVersion() ;

   /*----------------------------------------------------------------------*/
   protected :
      /*-------------------------------------------------------------------*/
      const CAvailableVersionData m_avd ;
      /*-------------------------------------------------------------------*/
      wxStaticText *m_stx_main_info ;
      wxTextCtrl   *m_txt_version_history ;
      wxBoxSizer   *m_bsz_btn ;
      wxButton     *m_bt_web_site ;
      wxButton     *m_bt_close ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      void OnBtGotoWebSite( wxCommandEvent &event ) ;
      void OnBtClose( wxCommandEvent &event )
      {  EndDialog( 0 ) ; }
      /*-------------------------------------------------------------------*/
      void build_ui() ;
      /*-------------------------------------------------------------------*/
      int get_modal() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CDlgLastVersion : public CDlgVersion
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CDlgLastVersion( wxWindow *parent,
                       const wxString &s_main_info,
                       const CAvailableVersionData &avd
                     ) ;
      ~CDlgLastVersion() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CDlgNewVersion : public CDlgVersion
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CDlgNewVersion( wxWindow *parent,
                      const wxString &s_main_info,
                      const CAvailableVersionData &avd
                    ) ;
      ~CDlgNewVersion() ;

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      wxButton *m_bt_download_install ;
      wxButton *m_bt_download ;
      /*-------------------------------------------------------------------*/
      wxFileName m_fn_local ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      virtual void OnBtDownload( wxCommandEvent &event ) ;
      virtual void OnBtDownloadInstall( wxCommandEvent &event ) ;
      /*-------------------------------------------------------------------*/
      int download( const wxFileName &fn_local = wxFileName(),
                    CDlgDownload::e_option ddo_option=CDlgDownload::DDO_NONE
                  ) ;
      int install() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
enum e_chkupd_freq { CUF_NEVER, CUF_DAY, CUF_WEEK, CUF_MONTH, CUF_NB } ;
void fill_cho_chkupd_freq( wxChoice *cho_chkupd_freq ) ;
wxString next_chkupd_iso( const wxString &s_last, int i_freq ) ;
bool check_version_needed( const wxString &s_last, int i_freq ) ;
void check_version( int i_err_code, const wxString &s_data,
                    bool boo_manual_check
                  ) ;

/*-------------------------------------------------------------------------*/
} ; // namespace sc
/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                         End of file sc_version.h                          !
+==========================================================================*/
