/*====================================+=====================================+
! File CDlgFirstContact.cpp           ! Copyright (C) 2018-2020 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This file is part of kimfo.                                               !
! It is free software: you can redistribute it and/or modify it under the   !
! terms of the GNU General Public License as published by the Free Software !
! Foundation, either version 3 of the License, or any later version.        !
! This application is distributed in the hope that it will be useful, but   !
! WITHOUT ANY WARRANTY; without even the implied warranty of                !
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General !
! Public License for more details.                                          !
! You should have received a copy of the GNU General Public License along   !
! with this application. If not, see <http://www.gnu.org/licenses/>.        !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#include <wx/dc.h>
#include <wx/renderer.h>
#include "CApp.h"
#include "CFrame.h"
#include "CServerList.h"
#include "CDlgFirstContact.h"
#include "tango/media_playback_start_16x16.xpm"
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
CDlgFirstContact::CDlgFirstContact( wxWindow *parent )
                : wxDialog( parent, wxID_ANY, _( "Fist contact" ) )
{
   /*----------------------------------------------------------------------*/
   wxBoxSizer *bsz_gen = new wxBoxSizer( wxVERTICAL ) ;
   wxBoxSizer *bsz_pan = new wxBoxSizer( wxVERTICAL ) ;
   wxBoxSizer *bsz_inf = new wxBoxSizer( wxVERTICAL ) ;
   /*----------------------------------------------------------------------*/
   wxPanel *panel = new wxPanel( this, wxID_ANY, wxDefaultPosition,
                                 wxDefaultSize, wxBORDER_SUNKEN
                               ) ;
   panel->SetBackgroundColour(
                           wxSystemSettings::GetColour( wxSYS_COLOUR_WINDOW )
                             ) ;
   panel->SetSizer( bsz_pan ) ;
   /*----------------------------------------------------------------------*/
   wxStaticText *stx_start
    = new wxStaticText( panel, wxID_ANY, _( "How to use this program ?" ) ) ;
   stx_start->SetFont( stx_start->GetFont().Bold() ) ;
   bsz_inf->Add( stx_start, 0, wxALL, 5 ) ;
   /*----------------------------------------------------------------------*/
   bsz_inf->AddSpacer( 10 ) ;
   /*----------------------------------------------------------------------*/
   {
      /*-------------------------------------------------------------------*/
      wxBoxSizer       *bsz_select = new wxBoxSizer( wxHORIZONTAL ) ;
      wxRendererNative &renderer = wxRendererNative::Get() ;
      wxBitmap         bmp_cb( 16, 16 ) ;
      wxMemoryDC      dc ;
      /*-------------------------------------------------------------------*/
      dc.SelectObject( bmp_cb ) ;
      dc.Clear() ;
      renderer.DrawCheckBox( this, dc, wxRect( bmp_cb.GetSize() ),
                             wxCONTROL_FLAT | wxCONTROL_CHECKED
                           ) ;
      dc.SelectObject( wxNullBitmap ) ;
      /*-------------------------------------------------------------------*/
      bsz_select->Add( new wxStaticBitmap( panel, wxID_ANY, bmp_cb ),
                       0, wxALL, 5
                     ) ;
      bsz_select->Add( new wxStaticText( panel, wxID_ANY,
                              _( "Select the servers you are interested in" )
                                       ),
                       0, wxALIGN_CENTER_VERTICAL
                     ) ;
      bsz_inf->Add( bsz_select ) ;
      /*-------------------------------------------------------------------*/
   }
   /*----------------------------------------------------------------------*/
   wxMenuBar *menubar = wxGetApp().m_frame->GetMenuBar() ;

   /*--( Availability )----------------------------------------------------*/
   wxBoxSizer *bsz_avail = new wxBoxSizer( wxVERTICAL ) ;
   bsz_avail->Add( new wxStaticText( panel, wxID_ANY,
                                     _( "Check their availability :" )
                                   ),
                   0, wxALL, 5
                 ) ;
   /*--( Availability "manual" )-------------------------------------------*/
   wxBoxSizer *bsz_avail_manu = new wxBoxSizer( wxHORIZONTAL ) ;
   wxStaticBitmap *stbmp_avail_manu
   = new wxStaticBitmap( panel, wxID_ANY,
                         menubar->FindItem( ID_CHECK_AVAIL )->GetBitmap()
                       ) ;
   bsz_avail_manu->Add( stbmp_avail_manu, 0, wxALL, 5 ) ;
   bsz_avail_manu->Add( new wxStaticText( panel, wxID_ANY, _( "manually" ) ),
                        0, wxALIGN_CENTER_VERTICAL
                      ) ;
   bsz_avail->Add( bsz_avail_manu, 0, wxLEFT, 20 ) ;
   /*--( Availability "auto" )---------------------------------------------*/
   wxBoxSizer *bsz_avail_auto = new wxBoxSizer( wxHORIZONTAL ) ;
   wxStaticBitmap *stbmp_avail_auto
   = new wxStaticBitmap( panel, wxID_ANY,
                         /*--( The menu icon is dynamically changed )------*/
                         wxBitmap( media_playback_start_16x16_xpm )
                       ) ;
   bsz_avail_auto->Add( stbmp_avail_auto, 0, wxALL, 5 ) ;
   bsz_avail_auto->Add( new wxStaticText( panel, wxID_ANY,
                                          _( "automatically" )
                                        ),
                        0, wxALIGN_CENTER_VERTICAL
                      ) ;
   bsz_avail->Add( bsz_avail_auto, 0, wxLEFT, 20 ) ;

   bsz_inf->Add( bsz_avail ) ;

   /*----------------------------------------------------------------------*/
   wxBoxSizer *bsz_result = new wxBoxSizer( wxHORIZONTAL ) ;
   bsz_result->Add( new wxStaticText( panel, wxID_ANY,
                                      _( "When a server will be available "
                                         "the main window will pop up"
                                      )
                                    ),
                    0, wxALIGN_CENTER_VERTICAL
                  ) ;
   bsz_inf->Add( bsz_result, 0, wxALL, 5 ) ;

   /*----------------------------------------------------------------------*/
   wxStaticText *stx_note
    = new wxStaticText( panel, wxID_ANY,
                  _( "Note : a double-click on a server opens its web page" )
                      ) ;
   stx_note->SetFont( stx_note->GetFont().Smaller() ) ;
   bsz_inf->Add( stx_note, 0, wxALL, 5 ) ;
   /*----------------------------------------------------------------------*/
   bsz_pan->Add( bsz_inf, 0, wxEXPAND | wxALL, 30 ) ;
   bsz_gen->Add( panel, 0, wxEXPAND | wxALL, 5 ) ;
   /*----------------------------------------------------------------------*/
   bsz_gen->Add( new wxButton( this, wxID_OK ),
                 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 5
               ) ;
   /*----------------------------------------------------------------------*/
   SetSizer( bsz_gen ) ;
   /*----------------------------------------------------------------------*/
   Layout() ;
   SetInitialSize() ;
   CentreOnParent() ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
int CDlgFirstContact::get_modal()
{
   /*----------------------------------------------------------------------*/
   return ShowModal() ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                     End of file CDlgFirstContact.cpp                      !
+==========================================================================*/
